.. _installation_guide:

Installation Guide
==================


Installing with PIP
-------------------

The easiest way to install **homely** is using ``pip``. Note that you will need
a python3 ``pip`` (``pip3``) because **homely** isn't backwards compatible with
python2.

1. If your system doesn't have ``pip3`` installed, you can run
   ``python3 -m ensurepip --user`` or follow the
   `installation instructions for pip
   <https://pip.pypa.io/en/stable/installing/>`_.
#. Run ``pip3 install --user homely``.


You can use ``homely --version`` to check that you have the latest version
installed:

.. parsed-literal::

    $ homely --version
    homely |homely_version|
